@@ -38,7 +38,7 @@ bwplot(s)
 ##D idx <- seq(as.Date('2008-01-15'), as.Date('2008-12-15'), 'month')
 ##D 
 ##D SISmm <- setZ(stackSIS, idx)
-##D layerNames(SISmm) <- month.abb
+##D names(SISmm) <- month.abb
 ##D 
 ##D bwplot(SISmm)
 ##D bwplot(SISmm, FUN=as.yearqtr)##FUN applies to z if not NULL
@@ -56,7 +56,7 @@ bwplot(s)
 ##D 
 ##D 
 ##D s <- stack(pop, landClass)
-##D layerNames(s) <- c('pop', 'landClass')
+##D names(s) <- c('pop', 'landClass')
 ##D 
 ##D bwplot(asinh(pop) ~ landClass|cut(y, 3), data=s,
 ##D        layout=c(3, 1), violin=FALSE)
@@ -118,7 +118,7 @@ chosen_s
 ##D idx <- seq(as.Date('2008-01-15'), as.Date('2008-12-15'), 'month')
 ##D 
 ##D SISmm <- setZ(stackSIS, idx)
-##D layerNames(SISmm) <- month.abb
+##D names(SISmm) <- month.abb
 ##D 
 ##D levelplot(SISmm)
 ##D 
@@ -171,7 +171,7 @@ densityplot(s)
 ##D idx <- seq(as.Date('2008-01-15'), as.Date('2008-12-15'), 'month')
 ##D 
 ##D SISmm <- setZ(stackSIS, idx)
-##D layerNames(SISmm) <- month.abb
+##D names(SISmm) <- month.abb
 ##D 
 ##D densityplot(SISmm)
 ##D densityplot(SISmm, FUN=as.yearqtr)##FUN applies to z if not NULL
@@ -189,7 +189,7 @@ densityplot(s)
 ##D 
 ##D 
 ##D s <- stack(pop, landClass)
-##D layerNames(s) <- c('pop', 'landClass')
+##D names(s) <- c('pop', 'landClass')
 ##D 
 ##D densityplot(~asinh(pop)|landClass, data=s,
 ##D             scales=list(relation='free'),
@@ -214,7 +214,7 @@ flush(stderr()); flush(stdout())
 ## Not run: 
 ##D r <- raster(system.file("external/test.grd", package="raster"))
 ##D s <- stack(r, r*2)
-##D layerNames(s) <- c('meuse', 'meuse x 2')
+##D names(s) <- c('meuse', 'meuse x 2')
 ##D 
 ##D library(ggplot2)
 ##D 
@@ -243,7 +243,7 @@ flush(stderr()); flush(stdout())
 
 f <- system.file("external/test.grd", package="raster")
 r <- raster(f)
-layerNames(r)
+names(r)
 
 xyplot(test~y, data=r, alpha=0.5)
 
@@ -258,7 +258,7 @@ xyplot(test~y, data=r, alpha=0.5)
 ##D stackSIS <- stack(listFich)SISmm <- SISmm*24 ##from irradiance (W/m2) to irradiation Wh/m2
 ##D setwd(old)
 ##D 
-##D layerNames(SISmm) <- month.abb
+##D names(SISmm) <- month.abb
 ##D 
 ##D ##Relation between the January & February versus July radiation for four
 ##D ##differents longitude regions.
@@ -305,7 +305,7 @@ histogram(s)
 ##D idx <- seq(as.Date('2008-01-15'), as.Date('2008-12-15'), 'month')
 ##D 
 ##D SISmm <- setZ(stackSIS, idx)
-##D layerNames(SISmm) <- month.abb
+##D names(SISmm) <- month.abb
 ##D 
 ##D histogram(SISmm)
 ##D histogram(SISmm, FUN=as.yearqtr)
@@ -324,7 +324,7 @@ histogram(s)
 ##D 
 ##D 
 ##D s <- stack(pop, landClass)
-##D layerNames(s) <- c('pop', 'landClass')
+##D names(s) <- c('pop', 'landClass')
 ##D 
 ##D histogram(~asinh(pop)|landClass, data=s,
 ##D             scales=list(relation='free'),
@@ -363,7 +363,7 @@ flush(stderr()); flush(stdout())
 ##D idx <- seq(as.Date('2008-01-15'), as.Date('2008-12-15'), 'month')
 ##D 
 ##D SISmm <- setZ(stackSIS, idx)
-##D layerNames(SISmm) <- month.abb
+##D names(SISmm) <- month.abb
 ##D 
 ##D horizonplot(SISmm)
 ## End(Not run)
@@ -383,7 +383,7 @@ flush(stderr()); flush(stdout())
 ##D idx <- seq(as.Date('1970-01-01'), as.Date('2003-03-01'), by='month')
 ##D idx <- as.yearmon(idx)
 ##D SST <- setZ(SST, idx)
-##D layerNames(SST) <- as.character(idx)
+##D names(SST) <- as.character(idx)
 ##D horizonplot(SST)
 ## End(Not run)
 
@@ -418,13 +418,22 @@ flush(stderr()); flush(stdout())
 ##D idx <- seq(as.Date('2008-01-15'), as.Date('2008-12-15'), 'month')
 ##D 
 ##D SISmm <- setZ(stackSIS, idx)
-##D layerNames(SISmm) <- month.abb
+##D names(SISmm) <- month.abb
 ##D 
-##D hovmoller(SISmm, dirXY=y, xlab='Latitude')##latitude
-##D hovmoller(SISmm, dirXY=y, labels=FALSE, xlab='Latitude')##without labels
-##D hovmoller(SISmm, dirXY=y, add.contour=FALSE, xlab='Latitude')##without contours
+##D ## Latitude as default
+##D hovmoller(SISmm, xlab='Latitude')
 ##D 
-##D hovmoller(SISmm, dirXY=sqrt(x^2+y^2))##a function of coordinates...
+##D ## With contour lines and labels
+##D hovmoller(SISmm, labels=TRUE, add.contour=TRUE,
+##D           xlab='Latitude')
+##D 
+##D ## Smooth color regions with latticeExtra::panel.2dsmoother
+##D hovmoller(SISmm, panel=panel.2dsmoother, n=1000,
+##D           labels=FALSE, add.contour=TRUE,
+##D           xlab='Latitude')
+##D 
+##D ## Using a function of coordinates
+##D hovmoller(SISmm, dirXY=sqrt(x^2+y^2))
 ## End(Not run)
 
 ## Not run: 
@@ -442,8 +451,9 @@ flush(stderr()); flush(stdout())
 ##D idx <- seq(as.Date('1970-01-01'), as.Date('2003-03-01'), by='month')
 ##D idx <- as.yearmon(idx)
 ##D SST <- setZ(SST, idx)
-##D layerNames(SST) <- as.character(idx)
+##D names(SST) <- as.character(idx)
 ##D hovmoller(SST, panel=panel.levelplot.raster,
+##D           xscale.components=xscale.raster.subticks,
 ##D           interpolate=TRUE, par.settings=RdBuTheme)
 ## End(Not run)
 
@@ -467,6 +477,14 @@ f <- system.file("external/test.grd", package="raster")
 r <- raster(f)
 levelplot(r)
 
+## With subticks
+levelplot(r, xscale.components=xscale.raster.subticks,
+             yscale.components=yscale.raster.subticks)
+
+levelplot(r, xscale.components=xscale.raster.subticks,
+             yscale.components=yscale.raster.subticks,
+             scales=list(x=list(rot=30, cex=0.8)))
+
 ## defining the scales for the marginal plot
 levelplot(r, scales.margin=list(x=c(100, 600), y=c(100, 1000)))
 ## if a component of the list is null, it is internally calculated
@@ -479,11 +497,53 @@ s <- stack(r, r+500, r-500)
 levelplot(s, contour=TRUE)
 contourplot(s, labels=list(cex=0.4), cuts=12)
 
-##Add a layer of sampling points
-##and change the theme
+levelplot(s, names.attr=c('R', 'R + 500', 'R - 500'))
+
+## Add a layer of sampling points
+## and change the theme
 pts <- sampleRandom(r, size=20, sp=TRUE)
-levelplot(r, par.settings=BTCTheme) + layer(sp.points(pts, col='red'))
-contourplot(r, labels=FALSE) + layer(sp.points(pts, col='red'))
+
+## Using +.trellis and layer from latticeExtra
+levelplot(r, par.settings = BTCTheme) + layer(sp.points(pts, col = 'red'))
+contourplot(r, labels = FALSE) + layer(sp.points(pts, col = 'red'))
+
+## or with a custom panel function
+levelplot(r, par.settings=BTCTheme,
+          panel=function(...){
+            panel.levelplot(...)
+            sp.points(pts, col='red')
+            })
+
+
+## Categorical data
+r <- raster(nrow=10, ncol=10)
+r[] = 1
+r[51:100] = 3
+r[3:6, 1:5] = 5
+r <- ratify(r)
+     
+rat <- levels(r)[[1]]
+rat$landcover <- c('Pine', 'Oak', 'Meadow')
+levels(r) <- rat
+r
+
+levelplot(r, col.regions=c('palegreen', 'midnightblue', 'indianred1'))
+
+r2 <- raster(r)
+r2[] = 3
+r2[51:100] = 1
+r2[3:6, 1:5] = 5
+
+r3 <- init(r, function(n)sample(c(1, 3, 5), n, replace=TRUE))
+
+## Multilayer categorical Raster* are displayed only if their RATs are the same
+levels(r2) <- levels(r3) <- levels(r)
+
+s <- stack(r, r2, r3)
+names(s) <- c('A', 'B', 'C')
+
+levelplot(s)
+
 
 ## Not run: 
 ##D ##Solar irradiation data from CMSAF
@@ -500,7 +560,7 @@ contourplot(r, labels=FALSE) + layer(sp.points(pts, col='red'))
 ##D idx <- seq(as.Date('2008-01-15'), as.Date('2008-12-15'), 'month')
 ##D 
 ##D SISmm <- setZ(stackSIS, idx)
-##D layerNames(SISmm) <- month.abb
+##D names(SISmm) <- month.abb
 ##D 
 ##D levelplot(SISmm)
 ##D 
@@ -524,9 +584,9 @@ flush(stderr()); flush(stdout())
 if (require(rgl)) {
 data(volcano)
 r <- raster(volcano)
+extent(r) <- c(0, 610, 0, 870)
 drape <- cut(r, 5)
-plot3D(r, drape=drape, zfac=4)
-decorate3d(xlab = "x", ylab = "y", zlab = "z", axes=TRUE)
+plot3D(r, drape=drape, zfac=2)
 }
 
 
@@ -559,7 +619,7 @@ flush(stderr()); flush(stdout())
 ##D idx <- seq(as.Date('2008-01-15'), as.Date('2008-12-15'), 'month')
 ##D 
 ##D SISmm <- setZ(stackSIS, idx)
-##D layerNames(SISmm) <- month.abb
+##D names(SISmm) <- month.abb
 ##D 
 ##D splom(SISmm)
 ## End(Not run)
@@ -573,24 +633,53 @@ flush(stderr()); flush(stdout())
 
 ### Name: vectorplot-methods
 ### Title: Vector plots of Raster objects.
-### Aliases: vectorplot vectorplot,Raster-method
+### Aliases: vectorplot vectorplot,Raster-method streamplot
+###   streamplot,Raster-method streamplot,RasterStack-method
 ### Keywords: methods spatial
 
 ### ** Examples
 
-df <- expand.grid(x=seq(-2, 2, .1), y=seq(-2, 2, .1))
-df$z <- with(df, (3*x^2 + y)*exp(-x^2-y^2))
-r1 <- rasterFromXYZ(df)
-df$z <- with(df, x*exp(-x^2-y^2))
-r2 <- rasterFromXYZ(df)
-df$z <- with(df, y*exp(-x^2-y^2))
-r3 <- rasterFromXYZ(df)
+## Not run: 
+##D proj <- CRS('+proj=longlat +datum=WGS84')
+##D 
+##D df <- expand.grid(x=seq(-2, 2, .01), y=seq(-2, 2, .01))
+##D df$z <- with(df, (3*x^2 + y)*exp(-x^2-y^2))
+##D r1 <- rasterFromXYZ(df, crs=proj)
+##D df$z <- with(df, x*exp(-x^2-y^2))
+##D r2 <- rasterFromXYZ(df, crs=proj)
+##D df$z <- with(df, y*exp(-x^2-y^2))
+##D r3 <- rasterFromXYZ(df, crs=proj)
+##D s <- stack(r1, r2, r3)
+##D names(s) <- c('R1', 'R2', 'R3')
+##D 
+##D vectorplot(r1)
+##D vectorplot(r2, par.settings=RdBuTheme())
+##D vectorplot(r3, par.settings=PuOrTheme())
+##D 
+##D 
+##D ## If no cluster is provided, streamplot uses parallel::mclapply except
+##D ## with Windows. Therefore, next code could spend a long time under
+##D ## Windows.
+##D streamplot(r1)
+##D 
+##D ## With a cluster
+##D hosts <- rep('localhost', 4)
+##D cl <- makeCluster(hosts)
+##D streamplot(r2, cl=cl,
+##D            par.settings=streamTheme(symbol=brewer.pal(n=5,
+##D                                                       name='Reds')))
+##D stopCluster(cl)
+##D 
+##D ## Without parallel
+##D streamplot(r3, parallel=FALSE,
+##D            par.settings=streamTheme(symbol=brewer.pal(n=5,
+##D                                                       name='Greens')))
+##D 
+##D ## Configuration of droplets and streamlets
+##D streamplot(s, layout=c(1, 3), droplet=list(pc=.2), streamlet=list(L=20),
+##D            par.settings=streamTheme(cex=.6))
+## End(Not run)
 
-projection(r1) <- projection(r2) <- projection(r3) <- CRS("+proj=longlat +datum=WGS84")
-
-vectorplot(r1, par.settings=RdBuTheme)
-vectorplot(r2, par.settings=RdBuTheme)
-vectorplot(r3, par.settings=RdBuTheme)
 
 
 
@@ -643,7 +732,7 @@ flush(stderr()); flush(stdout())
 ##D idx <- seq(as.Date('2008-01-15'), as.Date('2008-12-15'), 'month')
 ##D 
 ##D SISmm <- setZ(stackSIS, idx)
-##D layerNames(SISmm) <- month.abb
+##D names(SISmm) <- month.abb
 ##D 
 ##D xyplot(SISmm)
 ## End(Not run)
